# sed  
Predicting Bioactivities of Ligand Molecules Targeting G Protein-coupled Receptors by Merging Sparse Screening of Extended Connectivity Fingerprints and Deep Neural Nets
Accurate prediction and interpretation of ligand bioactivities are essential for virtual screening and drug discovery.
SED, was proposed to predict ligand bioactivities and to recognize key substructures associated with GPCRs through the coupling of screening for Lasso of long extended-connectivity fingerprints (ECFPs) with deep neural network training.